@@ -6,6 +6,8 @@
 //
 /////////////////////////////////////////////////////////////////////////////
 
+#include "../Common/Common.h"
+
 #include "LanguageModel.h"
 
 using namespace Dasher;
@@ -17,40 +19,39 @@ using namespace std;
 
 ///////////////////////////////////////////////////////////////////
 
-CLanguageModel::CLanguageModel(CAlphabet* Alphabet, int Normalization)
-	: m_Alphabet(Alphabet), m_iNorm(Normalization)
+CLanguageModel::CLanguageModel(CAlphabet* Alphabet)
+	: m_Alphabet(Alphabet)
 {
-	m_iModelChars = m_Alphabet->GetNumberSymbols();
 	m_uniform = 50;
 }
 
 
 ///////////////////////////////////////////////////////////////////
 
-void CLanguageModel::EnterText(CNodeContext* NodeContext, string TheText)
+void CLanguageModel::EnterText(CContext* pContext, string TheText)
 {
 	vector<symbol> Symbols;
 	m_Alphabet->GetSymbols(&Symbols, &TheText, false);
 	for (unsigned int i=0; i<Symbols.size(); i++)
-		EnterSymbol((CContext*) NodeContext, (modelchar) Symbols[i]);
+		EnterSymbol(pContext, Symbols[i]);
 }
 
 ///////////////////////////////////////////////////////////////////
 
-void CLanguageModel::LearnText(CNodeContext* NodeContext, string* TheText, bool IsMore)
+void CLanguageModel::LearnText(CContext* Context, string* TheText, bool IsMore)
 {
 	vector<symbol> Symbols;
 	
 	m_Alphabet->GetSymbols(&Symbols, TheText, IsMore);
 	
 	for (unsigned int i=0; i<Symbols.size(); i++)
-		LearnSymbol((CContext*) NodeContext, (modelchar) Symbols[i]);
+		LearnSymbol( Context,  Symbols[i]);
 }
 
 ///////////////////////////////////////////////////////////////////
 
-bool CLanguageModel::GetNodeProbs(CNodeContext* Context, vector<symbol> &NewSymbols,
-		vector<unsigned int> &Groups, vector<unsigned int> &Probs)
+bool CLanguageModel::GetProbs(CContext* Context, vector<symbol> &NewSymbols,
+		vector<unsigned int> &Groups, vector<unsigned int> &Probs, int iNorm) const
 {
 	// make sure it is a valid context
 	if (Context) {
@@ -72,14 +73,13 @@ bool CLanguageModel::GetNodeProbs(CNodeContext* Context, vector<symbol> &NewSymb
 		if( real_s <= 0 )
 		  return false;
 
-		int norm( normalization() );
 		//		int control( norm * 0.1 ); // FIXME - control node fration is decided here
 
 		//		if( GetControlSymbol() != -1 )
 		//  norm -= control;
 
-		int uniform_add = ((norm / 1000 ) / real_s ) * m_uniform;
-		int nonuniform_norm = norm - real_s * uniform_add;
+		int uniform_add = ((iNorm / 1000 ) / real_s ) * m_uniform;
+		int nonuniform_norm = iNorm - real_s * uniform_add;
 
 		NewSymbols.resize(s);
 		Groups.resize(s);
@@ -89,14 +89,14 @@ bool CLanguageModel::GetNodeProbs(CNodeContext* Context, vector<symbol> &NewSymb
 		}
 		GetProbs((CContext*) Context,Probs,nonuniform_norm);
 
-		for( unsigned int i(0); i < Probs.size(); ++i )
-		  if( isRealSymbol(NewSymbols[i] ) )
-		    Probs[i] += uniform_add;
+		for( int k=0; k < Probs.size(); ++k )
+		  if( isRealSymbol(NewSymbols[k] ) )
+		    Probs[k] += uniform_add;
 
 		    int tot(0);
 		    
-		    for (int i=0;i<s;i++) {
-		      tot += Probs[i];
+		    for (int l=0;l<s;l++) {
+		      tot += Probs[l];
 		    }
 		    
 		    //		    std::cout << tot << " " << nonuniform_norm << " " << norm << " " << uniform_add << " " << real_s << std::endl;
@@ -108,17 +108,25 @@ bool CLanguageModel::GetNodeProbs(CNodeContext* Context, vector<symbol> &NewSymb
 	return false;
 }
 
-int CLanguageModel::GetColour(int character)
+int CLanguageModel::GetColour(int character) const
 {
   return m_Alphabet->GetColour(character);
 }
 
-int CLanguageModel::GetGroupColour(int group)
+int CLanguageModel::GetGroupColour(int group) const
 {
 	return m_Alphabet->GetGroupColour(group);
 }
 
-bool CLanguageModel::isRealSymbol( symbol _s ) {
+std::string CLanguageModel::GetGroupLabel(int group) const
+{
+    return m_Alphabet->GetGroupLabel(group);
+}
+
+///////////////////////////////////////////////////////////////////
+
+bool CLanguageModel::isRealSymbol( symbol _s ) const
+{
   if( _s  == 0 )
     return false;
   else if( _s == GetControlSymbol() )
@@ -126,3 +134,5 @@ bool CLanguageModel::isRealSymbol( symbol _s ) {
   else
     return true;
 }
+
+///////////////////////////////////////////////////////////////////
